# encoding: utf-8

require "logstash/codecs/base"
require "logstash/util/charset"

# The "xls" codec is mainly used for xls input
class LogStash::Codecs::Excel < LogStash::Codecs::Base
  config_name "excel"

  # The character encoding used in this input. Examples include "UTF-8"
  # and "cp1252"
  #
  # This setting is useful if your log files are in Latin-1 (aka cp1252)
  # or in another character set other than UTF-8.
  #
  # This only affects "plain" format logs since json is UTF-8 already.
  config :charset, :validate => ::Encoding.name_list, :default => "UTF-8"

  public
  def register
    @converter = LogStash::Util::Charset.new(@charset)
    @converter.logger = @logger
  end

  public
  def decode(data)
    if data.is_a? Hash
      line = ""
      data[:row].each do |col|
        line << "#{col};"
      end

      event = LogStash::Event.new("message" => @converter.convert(line.rstrip))
      event.tag("eof") if data[:eof]
      event["wsname"] = data[:wsname]
    end

    yield event
  end # def decode

  public
  def encode(event)
    @on_event.call data
  end # def encode
end # class LogStash::Codecs::Plain
